@@ -63,11 +63,8 @@
 
 #include <KItinerary/CountryDb>
 #include <KItinerary/JsonLdDocument>
-#include <KItinerary/Ticket>
-#include <kitinerary_version.h>
-#if KITINERARY_VERSION >= QT_VERSION_CHECK(5, 24, 41)
 #include <KItinerary/PriceUtil>
-#endif
+#include <KItinerary/Ticket>
 
 #include <KPkPass/Field>
 #include <KPkPass/Barcode>
@@ -116,20 +113,6 @@ class MatrixBeaconStub : public QObject
 };
 #endif
 
-#if KITINERARY_VERSION <QT_VERSION_CHECK(5, 24, 41)
-class DummyPriceUtil
-{
-    Q_GADGET
- public:
-    Q_INVOKABLE static bool hasPrice(const QVariant&) { return false; }
-    Q_INVOKABLE static bool canHavePrice(const QVariant&) { return false; }
-    Q_INVOKABLE static double price(const QVariant&) { return 0.0; }
-    Q_INVOKABLE static QString currency(const QVariant&) { return QString(); }
-    Q_INVOKABLE static void setPrice(QVariant&, double, const QString&) {}
-    Q_INVOKABLE static int decimalCount(QStringView) { return 2; }
-};
-#endif
-
 void registerKContactsTypes()
 {
     // ### this should move into a real QML plugin for KContacts
@@ -156,8 +139,8 @@ void registerKCalendarCoreTypes()
 
 void registerKPkPassTypes()
 {
-    qmlRegisterUncreatableType<KPkPass::Barcode>("org.kde.pkpass", 1, 0, "Barcode", {});
-    qmlRegisterUncreatableType<KPkPass::Field>("org.kde.pkpass", 1, 0, "Field", {});
+    qmlRegisterUncreatableMetaObject(KPkPass::Barcode::staticMetaObject, "org.kde.pkpass", 1, 0, "Barcode", {});
+    qmlRegisterUncreatableMetaObject(KPkPass::Field::staticMetaObject, "org.kde.pkpass", 1, 0, "Field", {});
     qmlRegisterUncreatableType<KPkPass::Pass>("org.kde.pkpass", 1, 0, "Pass", {});
     qmlRegisterUncreatableType<KPkPass::BoardingPass>("org.kde.pkpass", 1, 0, "BoardingPass", {});
 }
@@ -165,14 +148,10 @@ void registerKPkPassTypes()
 void registerKItineraryTypes()
 {
     qRegisterMetaType<KItinerary::KnowledgeDb::DrivingSide>();
-    qmlRegisterUncreatableType<KItinerary::Ticket>("org.kde.kitinerary", 1, 0, "Ticket", {});
+    qmlRegisterUncreatableMetaObject(KItinerary::Ticket::staticMetaObject, "org.kde.kitinerary", 1, 0, "Ticket", {});
     qmlRegisterUncreatableMetaObject(KItinerary::KnowledgeDb::staticMetaObject, "org.kde.kitinerary", 1, 0, "KnowledgeDb", {});
     qmlRegisterSingletonType("org.kde.itinerary", 1, 0, "PriceUtil", [](QQmlEngine*, QJSEngine *engine) -> QJSValue {
-#if KITINERARY_VERSION >= QT_VERSION_CHECK(5, 24, 41)
         return engine->toScriptValue(KItinerary::PriceUtil());
-#else
-        return engine->toScriptValue(DummyPriceUtil());
-#endif
     });
 }
 
@@ -185,11 +164,11 @@ void registerApplicationTypes()
     qRegisterMetaType<Permission::Permission>();
     qRegisterMetaType<HealthCertificateManager*>();
 
-    qmlRegisterUncreatableType<LocationInformation>("org.kde.itinerary", 1, 0, "LocationInformation", {});
-    qmlRegisterUncreatableType<StatisticsItem>("org.kde.itinerary", 1, 0, "StatisticsItem", {});
-    qmlRegisterUncreatableType<TimelineElement>("org.kde.itinerary", 1, 0, "TimelineElement", {});
+    qmlRegisterUncreatableMetaObject(LocationInformation::staticMetaObject, "org.kde.itinerary", 1, 0, "LocationInformation", {});
+    qmlRegisterUncreatableMetaObject(StatisticsItem::staticMetaObject, "org.kde.itinerary", 1, 0, "StatisticsItem", {});
+    qmlRegisterUncreatableMetaObject(TimelineElement::staticMetaObject, "org.kde.itinerary", 1, 0, "TimelineElement", {});
     qmlRegisterUncreatableType<TimelineModel>("org.kde.itinerary", 1, 0, "TimelineModel", {});
-    qmlRegisterUncreatableType<Transfer>("org.kde.itinerary", 1, 0, "Transfer", {});
+    qmlRegisterUncreatableMetaObject(Transfer::staticMetaObject, "org.kde.itinerary", 1, 0, "Transfer", {});
 
     qmlRegisterUncreatableMetaObject(Permission::staticMetaObject, "org.kde.itinerary", 1, 0, "Permission", {});
 #if HAVE_MATRIX
@@ -329,13 +308,9 @@ int main(int argc, char **argv)
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
     QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
     QCoreApplication::setApplicationVersion(QStringLiteral(ITINERARY_VERSION_STRING));
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
-    QQuickStyle::setStyle(QStringLiteral("Material"));
+    QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
 #else
     QIcon::setFallbackThemeName(QStringLiteral("breeze"));
     QApplication app(argc, argv); // for native file dialogs
@@ -354,7 +329,7 @@ int main(int argc, char **argv)
     aboutData.setLicense(KAboutLicense::LGPL_V2, KAboutLicense::OrLaterVersions);
     aboutData.setHomepage(QStringLiteral("https://apps.kde.org/itinerary"));
     aboutData.setShortDescription(i18n("Digital Travel Assistant"));
-    aboutData.setCopyrightStatement(i18n("Copyright © 2018-%1 The KDE Community", QStringLiteral("2022")));
+    aboutData.setCopyrightStatement(i18n("Copyright © The KDE Community"));
     aboutData.setDesktopFileName(QStringLiteral("org.kde.itinerary"));
     KAboutData::setApplicationData(aboutData);
 
@@ -493,7 +468,7 @@ int main(int argc, char **argv)
     auto l10nContext = new KLocalizedContext(&engine);
     l10nContext->setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
     engine.rootContext()->setContextObject(l10nContext);
-    engine.load(QStringLiteral("qrc:/main.qml"));
+    engine.load(QStringLiteral("qrc:/qt/qml/org/kde/itinerary/main.qml"));
 
     // Exit on QML load error.
     if (engine.rootObjects().isEmpty()) {
