@@ -40,6 +40,9 @@ public:
         TripGroupRole,
         TransferRole,
         StartDateTimeRole,
+        EndDateTimeRole,
+        IsTimeboxedRole,
+        IsCanceledRole,
     };
     Q_ENUM(Role)
 
@@ -97,7 +100,9 @@ private:
     void updateTransfersForBatch(const QString &batchId);
 
     void scheduleCurrentBatchTimer();
+    bool isDateEmpty(const QDate &date) const;
 
+    friend class TimelineElement;
     ReservationManager *m_resMgr = nullptr;
     WeatherForecastManager *m_weatherMgr = nullptr;
     TripGroupManager *m_tripGroupManager = nullptr;
