@@ -18,9 +18,9 @@
 #include <QColor>
 #include <QDateTime>
 #include <QFile>
+#include <QImage>
 #include <QTimeZone>
 #include <QUrl>
-#include <QXmlStreamReader>
 
 #include <cmath>
 
@@ -93,55 +93,6 @@ void Util::sortModel(QObject *model, int column, Qt::SortOrder sortOrder)
     }
 }
 
-float Util::svgAspectRatio(const QString &svgFilePath)
-{
-    if (svgFilePath.isEmpty()) {
-        return 1.0f;
-    }
-
-    QString localFilePath(svgFilePath);
-    if (svgFilePath.startsWith(QLatin1String("qrc:"))) {
-        localFilePath = QLatin1Char(':') + QUrl(svgFilePath).path();
-    }
-    if (svgFilePath.startsWith(QLatin1String("file:"))) {
-        localFilePath = QUrl(svgFilePath).toLocalFile();
-    }
-    QFile file(localFilePath);
-    if (!file.open(QFile::ReadOnly)) {
-        qCWarning(Log) << file.errorString() << localFilePath;
-        return 1.0f;
-    }
-
-    QXmlStreamReader reader(&file);
-    while (!reader.atEnd()) {
-        if (reader.readNext() != QXmlStreamReader::StartElement) {
-            continue;
-        }
-        if (reader.name() != QLatin1String("svg")) {
-            qCDebug(Log) << svgFilePath << "not an svg file?";
-            return 1.0f;
-        }
-        const auto viewBox = reader.attributes().value(QLatin1String("viewBox"));
-        const auto parts = viewBox.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-        if (parts.size() != 4) {
-            qCDebug(Log) << "invalid SVG viewBox:" << viewBox;
-            return 1.0f;
-        }
-
-        bool widthValid, heightValid;
-        const auto width = parts.at(2).toDouble(&widthValid);
-        const auto height = parts.at(3).toDouble(&heightValid);
-        if (!widthValid || !heightValid || height == 0.0f || width == 0.0f) {
-            qCDebug(Log) << "invalid SVG viewBox:" << viewBox;
-            return 1.0f;
-        }
-
-        return width / height;
-    }
-
-    return 1.0f;
-}
-
 bool Util::isValidColor(const QColor &color)
 {
     return color.isValid();
@@ -152,4 +103,23 @@ bool Util::isLocationChange(const QVariant &res)
     return LocationUtil::isLocationChange(res);
 }
 
+bool Util::isDarkImage(const QImage &img)
+{
+    constexpr auto SAMPLE_COUNT = 32;
+
+    const auto xStride = std::max(1, img.width() / SAMPLE_COUNT);
+    const auto yStride = std::max(1, img.height() / SAMPLE_COUNT);
+    int darkCount = 0;
+
+    for (auto x = xStride; x < img.width(); x += xStride) {
+        for (auto y = yStride; y < img.height(); y += yStride) {
+            if (qGray(img.pixel(x, y)) < 128) {
+                ++darkCount;
+            }
+        }
+    }
+
+    return darkCount > (SAMPLE_COUNT * SAMPLE_COUNT / 2);
+}
+
 #include "moc_util.cpp"
